# Changelog

## 1.1.0 (2025-06-07)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/oregister/openregister-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** update via SDK Studio ([87a3573](https://github.com/oregister/openregister-python/commit/87a3573991bc19fadd1c4c92c1d90fab80687c7f))

## 1.0.1 (2025-06-07)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/oregister/openregister-python/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([722cc66](https://github.com/oregister/openregister-python/commit/722cc66631a7d16ed42771fcff10b2382c1ee6f1))

## 1.0.0 (2025-06-07)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/oregister/openregister-python/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([a018c07](https://github.com/oregister/openregister-python/commit/a018c0797b5296e8029e051d36dda94c909b0128))


### Chores

* configure new SDK language ([82da76d](https://github.com/oregister/openregister-python/commit/82da76d60986b6e1a49752ff77d7616f7e022aab))
* update SDK settings ([b3e38ee](https://github.com/oregister/openregister-python/commit/b3e38ee33379b4d063bef466fcbc69672d266815))
* update SDK settings ([145faf6](https://github.com/oregister/openregister-python/commit/145faf6f39192c044fd30bed4395085af8a487ac))
* update SDK settings ([8c2aa41](https://github.com/oregister/openregister-python/commit/8c2aa412e3660f742e3febc22364937dfb373cc4))
